@@ -8,7 +8,7 @@
 #include <time.h>
 #include "owl.h"
 
-static const char fileIdent[] = "$Id: global.c,v 1.32 2004/03/01 17:43:22 nygren Exp $";
+static const char fileIdent[] = "$Id: global.c,v 1.35 2005/01/30 17:26:44 kretch Exp $";
 
 #ifndef MAXHOSTNAMELEN
 #define MAXHOSTNAMELEN 256
@@ -119,20 +119,18 @@ void _owl_global_setup_windows(owl_global *g) {
 
   /* set the new window sizes */
   g->recwinlines=g->lines-(typwin_lines+2);
-  if (g->recwinlines<1) {
-    /* this will screw things up.  I'm not sure what to do yet,
-       but this is better than nothing */
-    /* g->recwinlines=1; */
+  if (g->recwinlines<0) {
+    /* gotta deal with this */
+    g->recwinlines=0;
   }
 
+  owl_function_debugmsg("_owl_global_setup_windows: about to call newwin(%i, %i, 0, 0)\n", g->recwinlines, cols);
+
   /* create the new windows */
   g->recwin=newwin(g->recwinlines, cols, 0, 0);
   if (g->recwin==NULL) {
-    owl_function_debugmsg("\n\nI just received an error on creating a new receive window\n");
-    owl_function_debugmsg("newwin was called with arguments (%i, %i, 0, 0) and returned NULL\n",
-	   g->recwinlines, cols);
+    owl_function_debugmsg("_owl_global_setup_windows: newwin returned NULL\n", g->recwinlines, cols);
     endwin();
-
     exit(50);
   }
       
@@ -393,7 +391,7 @@ void owl_global_resize(owl_global *g, int x, int y) {
     g->cols=y;
   }
 
-  /* resizeterm(size.ws_row, size.ws_col); */
+  resizeterm(size.ws_row, size.ws_col);
 
   /* re-initialize the windows */
   _owl_global_setup_windows(g);
@@ -885,3 +883,8 @@ owl_zbuddylist *owl_global_get_zephyr_buddylist(owl_global *g)
 {
   return(&(g->zbuddies));
 }
+
+struct termios *owl_global_get_startup_tio(owl_global *g)
+{
+  return(&(g->startup_tio));
+}
