@@ -2,7 +2,7 @@
 #include <string.h>
 #include "owl.h"
 
-static const char fileIdent[] = "$Id: keybinding.c,v 1.3 2003/06/30 22:12:41 kretch Exp $";
+static const char fileIdent[] = "$Id: keybinding.c,v 1.4 2005/01/30 17:26:44 kretch Exp $";
 
 /*
  * TODO: Idea for allowing functions to be user-specified --- 
@@ -18,7 +18,7 @@ int owl_keybinding_init(owl_keybinding *kb, char *keyseq, char *command, void (*
   char **ktokens;
   int    nktokens, i;
   
-  owl_function_debugmsg("creating binding for <%s> with desc: <%s>\n", keyseq, desc);
+  owl_function_debugmsg("owl_keybinding_init: creating binding for <%s> with desc: <%s>", keyseq, desc);
   if (command && !function_fn) {
     kb->type = OWL_KEYBINDING_COMMAND;
   } else if (!command && function_fn) {
