@@ -4,37 +4,101 @@
 #include <ctype.h>
 #include <sys/param.h>
 
-static const char fileIdent[] = "$Id: logging.c,v 1.22 2004/02/23 06:15:42 kretch Exp $";
+static const char fileIdent[] = "$Id: logging.c,v 1.24 2005/01/05 04:29:48 kretch Exp $";
 
-void owl_log_outgoing_zephyr(char *to, char *text)
+/* This is now the one function that should be called to log a
+ * message.  It will do all the work necessary by calling the other
+ * functions in this file as necessary.
+ */
+void owl_log_message(owl_message *m) {
+  owl_function_debugmsg("owl_log_message: entering");
+
+  /* should we be logging this message? */
+  if (!owl_log_shouldlog_message(m)) {
+    owl_function_debugmsg("owl_log_message: not logging message");
+    return;
+  }
+
+  /* handle incmoing messages */
+  if (owl_message_is_direction_in(m)) {
+    owl_log_incoming(m);
+    owl_function_debugmsg("owl_log_message: leaving");
+    return;
+  }
+
+  /* handle outgoing messages */
+  if (owl_message_is_type_aim(m)) {
+    owl_log_outgoing_aim(m);
+  } else if (owl_message_is_type_zephyr(m)) {
+    owl_log_outgoing_zephyr(m);
+  } else if (owl_message_is_type_loopback(m)) {
+    owl_log_outgoing_loopback(m);
+  } else {
+    owl_function_error("Unknown message type for logging");
+  }
+  owl_function_debugmsg("owl_log_message: leaving");
+}
+
+/* Return 1 if we should log the given message, otherwise return 0 */
+int owl_log_shouldlog_message(owl_message *m) {
+  owl_filter *f;
+
+  /* If there's a logfilter and this message matches it, log */
+  f=owl_global_get_filter(&g, owl_global_get_logfilter(&g));
+  if (f && owl_filter_message_match(f, m)) return(1);
+
+  /* otherwise we do things based on the logging variables */
+
+  /* skip login/logout messages if appropriate */
+  if (!owl_global_is_loglogins(&g) && owl_message_is_loginout(m)) return(0);
+      
+  /* check for nolog */
+  if (!strcasecmp(owl_message_get_opcode(m), "nolog") || !strcasecmp(owl_message_get_instance(m), "nolog")) return(0);
+
+  /* check direction */
+  if ((owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_IN) && owl_message_is_direction_out(m)) {
+    return(0);
+  }
+  if ((owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_OUT) && owl_message_is_direction_in(m)) {
+    return(0);
+  }
+
+  if (owl_message_is_type_zephyr(m)) {
+    if (owl_message_is_personal(m) && !owl_global_is_logging(&g)) return(0);
+    if (!owl_message_is_personal(m) && !owl_global_is_classlogging(&g)) return(0);
+  } else {
+    if (owl_message_is_private(m) || owl_message_is_loginout(m)) {
+      if (!owl_global_is_logging(&g)) return(0);
+    } else {
+      if (!owl_global_is_classlogging(&g)) return(0);
+    }
+  }
+  return(1);
+}
+
+void owl_log_outgoing_zephyr(owl_message *m)
 {
   FILE *file;
   char filename[MAXPATHLEN], *logpath;
-  char *tobuff, *ptr="";
+  char *to, *text;
 
-  if (owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_IN) return;
-
-  tobuff=owl_malloc(strlen(to)+20);
-  strcpy(tobuff, to);
-
-  /* chop off a local realm */
-  ptr=strchr(tobuff, '@');
-  if (ptr && !strncmp(ptr+1, owl_zephyr_get_realm(), strlen(owl_zephyr_get_realm()))) {
-    *ptr='\0';
-  }
+  /* strip local realm */
+  to=short_zuser(owl_message_get_recipient(m));
 
   /* expand ~ in path names */
-  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", 
-				owl_global_get_homedir(&g));
+  logpath=owl_text_substitute(owl_global_get_logpath(&g), "~", owl_global_get_homedir(&g));
 
-  snprintf(filename, MAXPATHLEN, "%s/%s", logpath, tobuff);
+  text=owl_message_get_body(m);
+
+  snprintf(filename, MAXPATHLEN, "%s/%s", logpath, to);
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
     owl_free(logpath);
+    owl_free(to);
     return;
   }
-  fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
+  fprintf(file, "OUTGOING (owl): %s\n%s\n", to, text);
   if (text[strlen(text)-1]!='\n') {
     fprintf(file, "\n");
   }
@@ -45,41 +109,49 @@ void owl_log_outgoing_zephyr(char *to, char *text)
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
+    owl_free(to);
     return;
   }
-  fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
+  fprintf(file, "OUTGOING (owl): %s\n%s\n", to, text);
   if (text[strlen(text)-1]!='\n') {
     fprintf(file, "\n");
   }
   fclose(file);
 
-  owl_free(tobuff);
+  owl_free(to);
 }
 
 void owl_log_outgoing_zephyr_error(char *to, char *text)
 {
   FILE *file;
   char filename[MAXPATHLEN], *logpath;
-  char *tobuff, *ptr="";
+  char *tobuff, *zwriteline;
+  owl_message *m;
 
-  tobuff=owl_malloc(strlen(to)+20);
-  strcpy(tobuff, to);
+  /* create a present message so we can pass it to
+   * owl_log_shouldlog_message()
+   */
+  zwriteline=owl_sprintf("zwrite %s", to);
+  m=owl_function_make_outgoing_zephyr(text, zwriteline, "");
+  owl_free(zwriteline);
+  if (!owl_log_shouldlog_message(m)) {
+    owl_message_free(m);
+    return;
+  }
+  owl_message_free(m);
 
   /* chop off a local realm */
-  ptr=strchr(tobuff, '@');
-  if (ptr && !strncmp(ptr+1, owl_zephyr_get_realm(), strlen(owl_zephyr_get_realm()))) {
-    *ptr='\0';
-  }
+  tobuff=short_zuser(to);
 
   /* expand ~ in path names */
-  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", 
-				owl_global_get_homedir(&g));
+  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", owl_global_get_homedir(&g));
 
   snprintf(filename, MAXPATHLEN, "%s/%s", logpath, tobuff);
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
     owl_free(logpath);
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "ERROR (owl): %s\n%s\n", tobuff, text);
@@ -93,6 +165,7 @@ void owl_log_outgoing_zephyr_error(char *to, char *text)
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "ERROR (owl): %s\n%s\n", tobuff, text);
@@ -104,28 +177,31 @@ void owl_log_outgoing_zephyr_error(char *to, char *text)
   owl_free(tobuff);
 }
 
-void owl_log_outgoing_aim(char *to, char *text)
+void owl_log_outgoing_aim(owl_message *m)
 {
   FILE *file;
   char filename[MAXPATHLEN], *logpath;
-  char *tobuff, *normalto;
+  char *tobuff, *normalto, *text;
 
-  if (owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_IN) return;
+  owl_function_debugmsg("owl_log_outgoing_aim: entering");
 
-  normalto=owl_aim_normalize_screenname(to);
+  /* normalize and downcase the screenname */
+  normalto=owl_aim_normalize_screenname(owl_message_get_recipient(m));
   downstr(normalto);
   tobuff=owl_sprintf("aim:%s", normalto);
   owl_free(normalto);
 
   /* expand ~ in path names */
-  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", 
-				owl_global_get_homedir(&g));
+  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", owl_global_get_homedir(&g));
 
+  text=owl_message_get_body(m);
+  
   snprintf(filename, MAXPATHLEN, "%s/%s", logpath, tobuff);
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
     owl_free(logpath);
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
@@ -139,6 +215,7 @@ void owl_log_outgoing_aim(char *to, char *text)
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
@@ -150,25 +227,25 @@ void owl_log_outgoing_aim(char *to, char *text)
   owl_free(tobuff);
 }
 
-void owl_log_outgoing_loopback(char *text)
+void owl_log_outgoing_loopback(owl_message *m)
 {
   FILE *file;
   char filename[MAXPATHLEN], *logpath;
-  char *tobuff;
-
-  if (owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_IN) return;
+  char *tobuff, *text;
 
   tobuff=owl_sprintf("loopback");
 
   /* expand ~ in path names */
-  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", 
-				owl_global_get_homedir(&g));
+  logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", owl_global_get_homedir(&g));
+
+  text=owl_message_get_body(m);
 
   snprintf(filename, MAXPATHLEN, "%s/%s", logpath, tobuff);
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
     owl_free(logpath);
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
@@ -182,6 +259,7 @@ void owl_log_outgoing_loopback(char *text)
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for outgoing logging");
+    owl_free(tobuff);
     return;
   }
   fprintf(file, "OUTGOING (owl): %s\n%s\n", tobuff, text);
@@ -200,46 +278,27 @@ void owl_log_incoming(owl_message *m)
   char *frombuff=NULL, *from=NULL, *buff=NULL, *ptr;
   int len, ch, i, personal;
 
-  if (owl_global_get_loggingdirection(&g)==OWL_LOGGING_DIRECTION_OUT) return;
-
-  /* skip login/logout messages if appropriate */
-  if (!owl_global_is_loglogins(&g) && owl_message_is_loginout(m)) return;
-      
-  /* check for nolog */
-  if (!strcasecmp(owl_message_get_opcode(m), "nolog") ||
-      !strcasecmp(owl_message_get_instance(m), "nolog")) return;
-
-  /* this is kind of a mess */
+  /* figure out if it's a "personal" message or not */
   if (owl_message_is_type_zephyr(m)) {
     if (owl_message_is_personal(m)) {
       personal=1;
-      if (!owl_global_is_logging(&g)) return;
     } else {
       personal=0;
-      if (!owl_global_is_classlogging(&g)) return;
     }
   } else {
     if (owl_message_is_private(m) || owl_message_is_loginout(m)) {
       personal=1;
-      if (!owl_global_is_logging(&g)) return;
     } else {
       personal=0;
-      if (!owl_global_is_classlogging(&g)) return;
     }
   }
 
   if (owl_message_is_type_zephyr(m)) {
-    /* chop off a local realm for personal zephyr messages */
     if (personal) {
       if (owl_message_is_type_zephyr(m)) {
-	from=frombuff=owl_strdup(owl_message_get_sender(m));
-	ptr=strchr(frombuff, '@');
-	if (ptr && !strncmp(ptr+1, owl_zephyr_get_realm(), strlen(owl_zephyr_get_realm()))) {
-	  *ptr='\0';
-	}
+	from=frombuff=short_zuser(owl_message_get_sender(m));
       }
     } else {
-      /* we assume zephyr for now */
       from=frombuff=owl_strdup(owl_message_get_class(m));
     }
   } else if (owl_message_is_type_aim(m)) {
@@ -275,15 +334,12 @@ void owl_log_incoming(owl_message *m)
 
   /* create the filename (expanding ~ in path names) */
   if (personal) {
-    logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", 
-				  owl_global_get_homedir(&g));
+    logpath = owl_text_substitute(owl_global_get_logpath(&g), "~", owl_global_get_homedir(&g));
     snprintf(filename, MAXPATHLEN, "%s/%s", logpath, from);
     snprintf(allfilename, MAXPATHLEN, "%s/all", logpath);
 
   } else {
-    logpath = owl_text_substitute(owl_global_get_classlogpath(&g), "~", 
-				owl_global_get_homedir(&g));
-
+    logpath = owl_text_substitute(owl_global_get_classlogpath(&g), "~", owl_global_get_homedir(&g));
     snprintf(filename, MAXPATHLEN, "%s/%s", logpath, from);
   }
   owl_free(logpath);
@@ -291,6 +347,7 @@ void owl_log_incoming(owl_message *m)
   file=fopen(filename, "a");
   if (!file) {
     owl_function_error("Unable to open file for incoming logging");
+    owl_free(frombuff);
     return;
   }
 
@@ -299,6 +356,7 @@ void owl_log_incoming(owl_message *m)
     allfile=fopen(allfilename, "a");
     if (!allfile) {
       owl_function_error("Unable to open file for incoming logging");
+      owl_free(frombuff);
       fclose(file);
       return;
     }
