@@ -45,6 +45,7 @@
 #include <time.h>
 #include <sys/param.h>
 #include <sys/types.h>
+#include <termios.h>
 #include <sys/stat.h>
 #include "owl.h"
 
@@ -58,7 +59,7 @@
 int stderr_replace(void);
 #endif
 
-static const char fileIdent[] = "$Id: owl.c,v 1.82 2004/04/11 00:21:32 kretch Exp $";
+static const char fileIdent[] = "$Id: owl.c,v 1.88 2005/01/30 17:26:44 kretch Exp $";
 
 owl_global g;
 
@@ -76,6 +77,7 @@ int main(int argc, char **argv, char **env)
   time_t nexttime, now;
   struct tm *today;
   char *dir;
+  struct termios tio;
 #ifdef HAVE_LIBZEPHYR
   ZNotice_t notice;
 #endif
@@ -135,6 +137,8 @@ int main(int argc, char **argv, char **env)
     }
   }
 
+  owl_function_debugmsg("startup: Finished parsing arguments");
+
 #ifdef HAVE_LIBZEPHYR
   /* zephyr init */
   ret=owl_zephyr_initialize();
@@ -154,6 +158,14 @@ int main(int argc, char **argv, char **env)
   sigaction(SIGTERM, &sigact, NULL);
   sigaction(SIGHUP, &sigact, NULL);
 
+  /* save initial terminal settings */
+  tcgetattr(0, owl_global_get_startup_tio(&g));
+
+  /* turn ISTRIP off */
+  tcgetattr(0, &tio);
+  tio.c_iflag &= ~ISTRIP;
+  tcsetattr(0, TCSAFLUSH, &tio);
+
   /* screen init */
   if (!getenv("TERMINFO")) {
     sprintf(buff, "TERMINFO=%s", TERMINFO);
@@ -217,23 +229,19 @@ int main(int argc, char **argv, char **env)
   /* setup the built-in styles */
   owl_function_debugmsg("startup: creating built-in styles");
   s=owl_malloc(sizeof(owl_style));
-  owl_style_create_internal(s, "default", &owl_stylefunc_default,
-			    "Default message formatting");
+  owl_style_create_internal(s, "default", &owl_stylefunc_default, "Default message formatting");
   owl_global_add_style(&g, s);
 
   s=owl_malloc(sizeof(owl_style));
-  owl_style_create_internal(s, "basic", &owl_stylefunc_basic,
-			    "Basic message formatting.");
+  owl_style_create_internal(s, "basic", &owl_stylefunc_basic, "Basic message formatting.");
   owl_global_add_style(&g, s);
 #if 0
   s=owl_malloc(sizeof(owl_style));
-  owl_style_create_internal(s, "vt", &owl_stylefunc_vt,
-			    "VT message formatting.");
+  owl_style_create_internal(s, "vt", &owl_stylefunc_vt, "VT message formatting.");
   owl_global_add_style(&g, s);
 #endif
   s=owl_malloc(sizeof(owl_style));
-  owl_style_create_internal(s, "oneline", &owl_stylefunc_oneline,
-			    "Formats for one-line-per-message");
+  owl_style_create_internal(s, "oneline", &owl_stylefunc_oneline, "Formats for one-line-per-message");
   owl_global_add_style(&g, s);
 
   /* setup the default filters */
@@ -305,10 +313,10 @@ int main(int argc, char **argv, char **env)
   perlerr=owl_perlconfig_readconfig(configfile);
   if (perlerr) {
     endwin();
-    owl_function_error("Error parsing configfile\n");
-    fprintf(stderr, "\nError parsing configfile. (%s)\n", perlerr);
+    owl_function_error("Error parsing configfile: %s\n", perlerr);
+    fprintf(stderr, "\nError parsing configfile: %s\n", perlerr);
     fflush(stderr);
-    printf("\nError parsing configfile. (%s)\n", perlerr);
+    printf("\nError parsing configfile: %s\n", perlerr);
     fflush(stdout);
     exit(1);
   }
@@ -362,7 +370,7 @@ int main(int argc, char **argv, char **env)
     ret=owl_zephyr_loaddefaultsubs();
     
     /* load subscriptions from subs file */
-    ret2=owl_zephyr_loadsubs(NULL);
+    ret2=owl_zephyr_loadsubs(NULL, 0);
 
     if (ret || ret2) {
       owl_function_adminmsg("", "Error loading zephyr subscriptions");
@@ -487,7 +495,17 @@ int main(int argc, char **argv, char **env)
 	owl_message_create_from_znotice(m, &notice);
 #endif
       } else if (owl_global_messagequeue_pending(&g)) {
+	/* pick up the non-zephyr message in the message queue */
 	m=owl_global_messageuque_popmsg(&g);
+      } else {
+	/* Not supposed to happen, but we seem to get here on resizes */
+	owl_function_debugmsg("Bottomed out looking for zephyr");
+      }
+
+      /* If we didn't pick up a message for some reason, don't go on */
+      if (m==NULL) {
+	owl_function_debugmsg("m is null in main loop");
+	continue;
       }
       
       /* if this message it on the puntlist, nuke it and continue */
@@ -568,9 +586,7 @@ int main(int argc, char **argv, char **env)
       }
 
       /* log the message if we need to */
-      if (owl_global_is_logging(&g) || owl_global_is_classlogging(&g)) {
-	owl_log_incoming(m);
-      }
+      owl_log_message(m);
     }
 
     /* is it time to check zbuddies? */
