@@ -47,6 +47,7 @@
 #include <regex.h>
 #include <time.h>
 #include <signal.h>
+#include <termios.h>
 #include <libfaim/aim.h>
 #include "config.h"
 #ifdef HAVE_LIBZEPHYR
@@ -56,10 +57,10 @@
 #include <com_err.h>
 #endif
 
-static const char owl_h_fileIdent[] = "$Id: owl.h,v 1.113 2004/05/07 23:35:01 kretch Exp $";
+static const char owl_h_fileIdent[] = "$Id: owl.h,v 1.118 2005/01/01 00:11:43 kretch Exp $";
 
-#define OWL_VERSION         2.1.8
-#define OWL_VERSION_STRING "2.1.8"
+#define OWL_VERSION         2.1.11
+#define OWL_VERSION_STRING "2.1.11"
 
 /* Feature that is being tested to redirect stderr through a pipe. 
  * There may still be some portability problems with this. */
@@ -327,7 +328,7 @@ typedef struct _owl_message {
   owl_fmtext fmtext;              /* this is now only a CACHED copy */
   int invalid_format;             /* indicates whether fmtext needs to be regenerated */
   int delete;
-  char hostname[MAXHOSTNAMELEN+1];
+  char *hostname;
   owl_list attributes;            /* this is a list of pairs */
   char *timestr;
   time_t time;
@@ -560,6 +561,7 @@ typedef struct _owl_global {
   siginfo_t err_signal_info;
   owl_zbuddylist zbuddies;
   owl_timer zephyr_buddycheck_timer;
+  struct termios startup_tio;
 } owl_global;
 
 /* globals */
