@@ -1,18 +1,17 @@
 /* -------------------------------- aim.c -------------------------------- */
 extern void owl_aim_init(void);
 extern int owl_aim_login(char *screenname, char *password);
-#if 0
-#endif
 extern void owl_aim_successful_login(char *screenname);
 extern void owl_aim_logout(void);
+extern void owl_aim_logged_out();
 extern void owl_aim_login_error(char *message);
 extern int owl_aim_send_im(char *to, char *msg);
+extern int owl_aim_send_awaymsg(char *to, char *msg);
 extern void owl_aim_addbuddy(char *name);
 extern void owl_aim_delbuddy(char *name);
-#if 0
-extern void owl_aim_get_idle(char *screenname);
-#endif
-extern void owl_aim_chat_join(char *chatroom);
+extern void owl_aim_search(char *email);
+extern int owl_aim_set_awaymsg(char *msg);
+extern void owl_aim_chat_join(char *name, int exchange);
 extern void owl_aim_chat_leave(char *chatroom);
 extern int owl_aim_chat_sendmsg(char *chatroom, char *msg);
 extern char *owl_aim_normalize_screenname(char *in);
@@ -22,13 +21,14 @@ extern int faimtest_flapversion(aim_session_t *sess, aim_frame_t *fr, ...);
 #endif
 extern int faimtest_conncomplete(aim_session_t *sess, aim_frame_t *fr, ...);
 extern void addcb_bos(aim_session_t *sess, aim_conn_t *bosconn);
-extern int login(aim_session_t *sess, const char *sn, const char *passwd);
 extern int logout(aim_session_t *sess);
 #if 0
 #endif
 extern int faimtest_parse_genericerr(aim_session_t *sess, aim_frame_t *fr, ...);
 extern void chatnav_redirect(aim_session_t *sess, struct aim_redirect_data *redir);
 extern void chat_redirect(aim_session_t *sess, struct aim_redirect_data *redir);
+#if 0
+#endif
 
 /* -------------------------------- buddy.c -------------------------------- */
 extern void owl_buddy_create(owl_buddy *b, int proto, char *name);
@@ -83,8 +83,10 @@ extern char *owl_command_blist();
 extern char *owl_command_toggleoneline();
 extern void owl_command_about();
 extern void owl_command_version();
+extern char *owl_command_aim(int argc, char **argv, char *buff);
 extern char *owl_command_addbuddy(int argc, char **argv, char *buff);
 extern char *owl_command_delbuddy(int argc, char **argv, char *buff);
+extern char *owl_command_join(int argc, char **argv, char *buff);
 extern char *owl_command_startup(int argc, char **argv, char *buff);
 extern char *owl_command_unstartup(int argc, char **argv, char *buff);
 extern char *owl_command_dump(int argc, char **argv, char *buff);
@@ -108,6 +110,8 @@ extern char *owl_command_start_command(int argc, char **argv, char *buff);
 extern char *owl_command_start_question(int argc, char **argv, char *buff);
 extern char *owl_command_start_password(int argc, char **argv, char *buff);
 extern char *owl_command_zaway(int argc, char **argv, char *buff);
+extern char *owl_command_aaway(int argc, char **argv, char *buff);
+extern char *owl_command_away(int argc, char **argv, char *buff);
 extern char *owl_command_set(int argc, char **argv, char *buff);
 extern char *owl_command_unset(int argc, char **argv, char *buff);
 extern char *owl_command_print(int argc, char **argv, char *buff);
@@ -133,6 +137,7 @@ extern void owl_command_getsubs(void);
 extern void owl_command_status(void);
 extern char *owl_command_zwrite(int argc, char **argv, char *buff);
 extern char *owl_command_aimwrite(int argc, char **argv, char *buff);
+extern char *owl_command_loopwrite(int argc, char **argv, char *buff);
 extern char *owl_command_zcrypt(int argc, char **argv, char *buff);
 #ifdef OWL_ENABLE_ZCRYPT
 #else
@@ -150,6 +155,7 @@ extern char *owl_command_delete(int argc, char **argv, char *buff);
 extern char *owl_command_undelete(int argc, char **argv, char *buff);
 extern void owl_command_beep();
 extern char *owl_command_colorview(int argc, char **argv, char *buff);
+extern char *owl_command_colorclass(int argc, char **argv, char *buff);
 extern char *owl_command_zpunt(int argc, char **argv, char *buff);
 extern char *owl_command_zunpunt(int argc, char **argv, char *buff);
 extern void owl_command_zpunt_and_zunpunt(int argc, char **argv, int type);
@@ -251,6 +257,11 @@ extern char *owl_editwin_get_text(owl_editwin *e);
 extern int owl_editwin_get_numchars_on_line(owl_editwin *e, int line);
 extern int owl_editwin_get_numlines(owl_editwin *e);
 
+/* -------------------------------- errqueue.c -------------------------------- */
+extern void owl_errqueue_init(owl_errqueue *eq);
+extern void owl_errqueue_append_err(owl_errqueue *eq, char *msg);
+extern void owl_errqueue_to_fmtext(owl_errqueue *eq, owl_fmtext *fm);
+
 /* -------------------------------- filter.c -------------------------------- */
 extern int owl_filter_init_fromstring(owl_filter *f, char *name, char *string);
 extern int owl_filter_init(owl_filter *f, char *name, int argc, char **argv);
@@ -265,6 +276,8 @@ extern int owl_filter_message_match(owl_filter *f, owl_message *m);
 extern int _owl_filter_message_match_recurse(owl_filter *f, owl_message *m, owl_list *fes, int start, int end);
 extern void owl_filter_print(owl_filter *f, char *out);
 extern int owl_filter_equiv(owl_filter *a, owl_filter *b);
+extern void _owl_filter_get_subfilter_names(owl_filter *f, owl_list *list);
+extern int owl_filter_is_toodeep(owl_filter *f);
 extern void owl_filter_free(owl_filter *f);
 
 /* -------------------------------- filterelement.c -------------------------------- */
@@ -277,6 +290,8 @@ extern void owl_filterelement_create_not(owl_filterelement *fe);
 extern void owl_filterelement_create_true(owl_filterelement *fe);
 extern void owl_filterelement_create_false(owl_filterelement *fe);
 extern void owl_filterelement_create_re(owl_filterelement *fe, char *field, char *re);
+extern void owl_filterelement_create_filter(owl_filterelement *fe, char *name);
+extern void owl_filterelement_create_perl(owl_filterelement *fe, char *name);
 extern void owl_filterelement_free(owl_filterelement *fe);
 extern int owl_filterelement_is_null(owl_filterelement *fe);
 extern int owl_filterelement_is_openbrace(owl_filterelement *fe);
@@ -287,8 +302,11 @@ extern int owl_filterelement_is_not(owl_filterelement *fe);
 extern int owl_filterelement_is_true(owl_filterelement *fe);
 extern int owl_filterelement_is_false(owl_filterelement *fe);
 extern int owl_filterelement_is_re(owl_filterelement *fe);
+extern int owl_filterelement_is_perl(owl_filterelement *fe);
 extern owl_regex *owl_filterelement_get_re(owl_filterelement *fe);
+extern int owl_filterelement_is_filter(owl_filterelement *fe);
 extern char *owl_filterelement_get_field(owl_filterelement *fe);
+extern char *owl_filterelement_get_filtername(owl_filterelement *fe);
 extern int owl_filterelement_is_value(owl_filterelement *fe);
 extern char *owl_filterelement_to_string(owl_filterelement *fe);
 
@@ -305,11 +323,9 @@ extern void owl_fmtext_append_reverse(owl_fmtext *f, char *text);
 extern void owl_fmtext_append_reversebold(owl_fmtext *f, char *text);
 extern void owl_fmtext_addattr(owl_fmtext *f, int attr);
 extern void owl_fmtext_colorize(owl_fmtext *f, int color);
-extern void owl_fmtext_append_ztext(owl_fmtext *f, char *text);
 extern void _owl_fmtext_append_fmtext(owl_fmtext *f, owl_fmtext *in, int start, int stop);
 extern void owl_fmtext_append_fmtext(owl_fmtext *f, owl_fmtext *in);
 extern void owl_fmtext_append_spaces(owl_fmtext *f, int nspaces);
-extern void owl_fmtext_append_list(owl_fmtext *f, owl_list *l, char *join_with, char *(format_fn)(void*));
 extern char *owl_fmtext_print_plain(owl_fmtext *f);
 extern void owl_fmtext_curs_waddstr(owl_fmtext *f, WINDOW *w);
 extern int owl_fmtext_truncate_lines(owl_fmtext *in, int aline, int lines, owl_fmtext *out);
@@ -317,10 +333,12 @@ extern void owl_fmtext_truncate_cols(owl_fmtext *in, int acol, int bcol, owl_fmt
 extern int owl_fmtext_num_lines(owl_fmtext *f);
 extern char *owl_fmtext_get_text(owl_fmtext *f);
 extern void owl_fmtext_set_char(owl_fmtext *f, int index, int ch);
-extern void owl_fmtext_free(owl_fmtext *f);
 extern void owl_fmtext_copy(owl_fmtext *dst, owl_fmtext *src);
 extern int owl_fmtext_search_and_highlight(owl_fmtext *f, char *string);
 extern int owl_fmtext_search(owl_fmtext *f, char *string);
+extern void owl_fmtext_append_ztext(owl_fmtext *f, char *text);
+extern void owl_fmtext_append_list(owl_fmtext *f, owl_list *l, char *join_with, char *(format_fn)(void*));
+extern void owl_fmtext_free(owl_fmtext *f);
 
 /* -------------------------------- functions.c -------------------------------- */
 extern void owl_function_noop(void);
@@ -334,11 +352,15 @@ extern void owl_function_show_styles();
 extern char *owl_function_style_describe(void *name);
 extern char *owl_function_cmd_describe(void *name);
 extern void owl_function_show_command(char *name);
+extern void owl_function_show_license();
+extern int owl_function_add_message(owl_message *m);
 extern void owl_function_adminmsg(char *header, char *body);
-extern void owl_function_make_outgoing_zephyr(char *body, char *zwriteline, char *zsig);
-extern int owl_function_make_outgoing_aim(char *body, char *to);
+extern owl_message *owl_function_make_outgoing_zephyr(char *body, char *zwriteline, char *zsig);
+extern owl_message *owl_function_make_outgoing_aim(char *body, char *to);
+extern owl_message *owl_function_make_outgoing_loopback(char *body);
 extern void owl_function_zwrite_setup(char *line);
 extern void owl_function_aimwrite_setup(char *line);
+extern void owl_function_loopwrite_setup();
 extern void owl_function_zwrite(char *line, char *msg);
 extern void owl_function_zcrypt(char *line, char *msg);
 #ifdef OWL_ENABLE_ZCRYPT
@@ -347,6 +369,8 @@ extern void owl_function_zcrypt(char *line, char *msg);
 #else
 #endif
 extern void owl_function_aimwrite(char *to);
+extern void owl_function_send_aimawymsg(char *to, char *msg);
+extern void owl_function_loopwrite();
 extern void owl_function_nextmsg_full(char *filter, int skip_deleted, int last_if_none);
 extern void owl_function_prevmsg_full(char *filter, int skip_deleted, int first_if_none);
 extern void owl_function_nextmsg();
@@ -370,9 +394,10 @@ extern void owl_function_suspend();
 extern void owl_function_zaway_toggle();
 extern void owl_function_zaway_on();
 extern void owl_function_zaway_off();
+extern void owl_function_aaway_toggle();
+extern void owl_function_aaway_on();
+extern void owl_function_aaway_off();
 extern void owl_function_quit();
-extern void owl_function_makemsg(char *fmt, ...);
-extern void owl_function_errormsg(char *fmt, ...);
 extern void owl_function_openurl();
 extern void owl_function_calculate_topmsg(int direction);
 extern int owl_function_calculate_topmsg_top(int direction, owl_view *v, int curmsg, int topmsg, int recwinlines);
@@ -391,6 +416,7 @@ extern void owl_function_set_cursor(WINDOW *win);
 extern void owl_function_full_redisplay();
 extern void owl_function_popless_text(char *text);
 extern void owl_function_popless_fmtext(owl_fmtext *fm);
+extern void owl_function_popless_file(char *filename);
 extern void owl_function_about();
 extern void owl_function_info();
 #ifdef HAVE_LIBZEPHYR
@@ -411,6 +437,9 @@ extern void owl_function_show_variable(char *name);
 extern void owl_function_delete_by_id(int id, int flag);
 extern void owl_function_delete_automsgs();
 extern void owl_function_status();
+#if OWL_STDERR_REDIR
+#else
+#endif
 extern void owl_function_show_term();
 extern void owl_function_reply(int type, int enter);
 extern void owl_function_zlocate(int argc, char **argv, int auth);
@@ -418,12 +447,12 @@ extern void owl_function_start_command(char *line);
 extern void owl_function_start_question(char *line);
 extern void owl_function_start_password(char *line);
 extern char *owl_function_exec(int argc, char **argv, char *buff, int type);
+#if OWL_STDERR_REDIR
+#endif 
 extern char *owl_function_perl(int argc, char **argv, char *buff, int type);
-#if 0
-extern void owl_function_change_view_old(char *filtname);
-#endif
-extern void owl_function_change_view(char *filtname);
+extern void owl_function_change_currentview_filter(char *filtname);
 extern void owl_function_create_filter(int argc, char **argv);
+extern char *owl_function_create_negative_filter(char *filtername);
 extern void owl_function_show_filters();
 extern void owl_function_show_filter(char *name);
 extern void owl_function_show_zpunts();
@@ -435,6 +464,7 @@ extern void owl_function_delete_curview_msgs(int flag);
 extern char *owl_function_smartfilter(int type);
 extern void owl_function_smartzpunt(int type);
 extern void owl_function_color_current_filter(char *color);
+extern int owl_function_color_filter(char *filtname, char *color);
 extern void owl_function_show_colors();
 extern void owl_function_zpunt(char *class, char *inst, char *recip, int direction);
 extern void owl_function_activate_keymap(char *keymap);
@@ -446,7 +476,7 @@ extern void owl_function_search_start(char *string, int direction);
 extern void owl_function_search_continue(int direction);
 extern void owl_function_search_helper(int mode, int direction);
 extern char *owl_function_ztext_stylestrip(char *zt);
-extern void owl_function_buddylist(int aim, int zephyr, char *file);
+extern void owl_function_buddylist(int aim, int zephyr, char *filename);
 #ifdef HAVE_LIBZEPHYR
 #endif
 #ifdef HAVE_LIBZEPHYR
@@ -460,6 +490,13 @@ extern void owl_function_delstartup(char *buff);
 extern void owl_function_source(char *filename);
 extern void owl_function_change_style(owl_view *v, char *stylename);
 extern void owl_function_toggleoneline();
+extern void owl_function_error(char *fmt, ...);
+extern void owl_function_showerrs();
+extern void owl_function_makemsg(char *fmt, ...);
+extern void owl_function_zephyr_buddy_check(int notify);
+#ifdef HAVE_LIBZEPHYR
+#endif
+extern void owl_function_aimsearch_results(char *email, owl_list *namelist);
 
 /* -------------------------------- global.c -------------------------------- */
 #ifndef MAXHOSTNAMELEN
@@ -524,6 +561,7 @@ extern void owl_global_set_startupargs(owl_global *g, int argc, char **argv);
 extern char *owl_global_get_startupargs(owl_global *g);
 extern owl_history *owl_global_get_msg_history(owl_global *g);
 extern owl_history *owl_global_get_cmd_history(owl_global *g);
+extern owl_muxevents *owl_global_get_muxevents(owl_global *g);
 extern owl_list *owl_global_get_filterlist(owl_global *g);
 extern owl_filter *owl_global_get_filter(owl_global *g, char *name);
 extern void owl_global_add_filter(owl_global *g, owl_filter *f);
@@ -557,7 +595,8 @@ extern int owl_global_is_doaimevents(owl_global *g);
 extern void owl_global_set_doaimevents(owl_global *g);
 extern void owl_global_set_no_doaimevents(owl_global *g);
 extern aim_session_t *owl_global_get_aimsess(owl_global *g);
-extern aim_conn_t *owl_global_get_waitingconn(owl_global *g);
+extern aim_conn_t *owl_global_get_bosconn(owl_global *g);
+extern void owl_global_set_bossconn(owl_global *g, aim_conn_t *conn);
 extern int owl_global_is_aimnop_time(owl_global *g);
 extern void owl_global_aimnop_sent(owl_global *g);
 extern owl_timer *owl_global_get_aim_login_timer(owl_global *g);
@@ -575,12 +614,19 @@ extern int owl_global_is_haveaim(owl_global *g);
 extern void owl_global_set_havezephyr(owl_global *g);
 extern int owl_global_is_havezephyr(owl_global *g);
 extern owl_timer *owl_global_get_aim_buddyinfo_timer(owl_global *g);
+extern owl_errqueue *owl_global_get_errqueue(owl_global *g);
+extern void owl_global_set_errsignal(owl_global *g, int signum, siginfo_t *siginfo);
+extern int owl_global_get_errsignal_and_clear(owl_global *g, siginfo_t *siginfo);
+extern owl_timer *owl_global_get_zephyr_buddycheck_timer(owl_global *g);
+extern owl_zbuddylist *owl_global_get_zephyr_buddylist(owl_global *g);
+extern struct termios *owl_global_get_startup_tio(owl_global *g);
 
 /* -------------------------------- help.c -------------------------------- */
 extern void owl_help();
 
 /* -------------------------------- history.c -------------------------------- */
 extern void owl_history_init(owl_history *h);
+extern void owl_history_set_norepeats(owl_history *h);
 extern char *owl_history_get_prev(owl_history *h);
 extern char *owl_history_get_next(owl_history *h);
 extern void owl_history_store(owl_history *h, char *line);
@@ -645,8 +691,12 @@ extern void owl_list_free_all(owl_list *l, void (*elefree)(void *));
 extern void owl_list_free_simple(owl_list *l);
 
 /* -------------------------------- logging.c -------------------------------- */
-extern void owl_log_outgoing_zephyr(char *to, char *text);
-extern void owl_log_outgoing_aim(char *to, char *text);
+extern void owl_log_message(owl_message *m);
+extern int owl_log_shouldlog_message(owl_message *m);
+extern void owl_log_outgoing_zephyr(owl_message *m);
+extern void owl_log_outgoing_zephyr_error(char *to, char *text);
+extern void owl_log_outgoing_aim(owl_message *m);
+extern void owl_log_outgoing_loopback(owl_message *m);
 extern void owl_log_incoming(owl_message *m);
 
 /* -------------------------------- mainwin.c -------------------------------- */
@@ -688,14 +738,17 @@ extern int owl_message_is_logout(owl_message *m);
 extern void owl_message_set_isprivate(owl_message *m);
 extern int owl_message_is_private(owl_message *m);
 extern char *owl_message_get_timestr(owl_message *m);
+extern char *owl_message_get_shorttimestr(owl_message *m);
 extern void owl_message_set_type_admin(owl_message *m);
+extern void owl_message_set_type_loopback(owl_message *m);
 extern void owl_message_set_type_zephyr(owl_message *m);
 extern void owl_message_set_type_aim(owl_message *m);
 extern int owl_message_is_type_admin(owl_message *m);
+extern int owl_message_is_type_loopback(owl_message *m);
 extern int owl_message_is_type_zephyr(owl_message *m);
 extern int owl_message_is_type_aim(owl_message *m);
+extern int owl_message_is_pseudo(owl_message *m);
 extern int owl_message_is_type_generic(owl_message *m);
-extern char *owl_message_type_to_string(owl_message *m);
 extern char *owl_message_get_text(owl_message *m);
 extern void owl_message_set_direction_in(owl_message *m);
 extern void owl_message_set_direction_out(owl_message *m);
@@ -714,6 +767,7 @@ extern ZNotice_t *owl_message_get_notice(owl_message *m);
 #else
 extern void *owl_message_get_notice(owl_message *m);
 #endif
+extern void owl_message_set_hostname(owl_message *m, char *hostname);
 extern char *owl_message_get_hostname(owl_message *m);
 extern void owl_message_curs_waddstr(owl_message *m, WINDOW *win, int aline, int bline, int acol, int bcol, int color);
 extern int owl_message_is_personal(owl_message *m);
@@ -730,6 +784,7 @@ extern char *owl_message_get_header(owl_message *m);
 extern int owl_message_search(owl_message *m, char *string);
 extern void owl_message_create_aim(owl_message *m, char *sender, char *recipient, char *text, int direction, int loginout);
 extern void owl_message_create_admin(owl_message *m, char *header, char *text);
+extern void owl_message_create_loopback(owl_message *m, char *text);
 #ifdef HAVE_LIBZEPHYR
 extern void owl_message_create_from_znotice(owl_message *m, ZNotice_t *n);
 #ifdef OWL_ENABLE_ZCRYPT
@@ -737,6 +792,9 @@ extern void owl_message_create_from_znotice(owl_message *m, ZNotice_t *n);
 #else
 extern void owl_message_create_from_znotice(owl_message *m, void *n);
 #endif
+extern void owl_message_create_pseudo_zlogin(owl_message *m, int direction, char *user, char *host, char *time, char *tty);
+#ifdef HAVE_LIBZEPHYR
+#endif
 extern void owl_message_create_from_zwriteline(owl_message *m, char *line, char *body, char *zsig);
 extern void owl_message_pretty_zsig(owl_message *m, char *buff);
 extern void owl_message_free(owl_message *m);
@@ -754,22 +812,44 @@ extern int owl_messagelist_undelete_element(owl_messagelist *ml, int n);
 extern int owl_messagelist_expunge(owl_messagelist *ml);
 extern void owl_messagelist_invalidate_formats(owl_messagelist *ml);
 
+/* -------------------------------- muxevents.c -------------------------------- */
+extern int owl_muxevents_add(owl_muxevents *muxevents, int fd, int eventmask, void (*handler_fn)(int handle, int fd, int eventmask, void *data), void *data);
+extern void owl_muxevents_remove(owl_muxevents *muxevents, int handle);
+extern void owl_muxevents_gc(owl_muxevents *muxevents);
+extern void owl_muxevents_dispatch(owl_muxevents *muxevents, int timeout_usec);
+
 /* -------------------------------- owl.c -------------------------------- */
+#if OWL_STDERR_REDIR
+#ifdef HAVE_SYS_IOCTL_H
+#endif
+#ifdef HAVE_SYS_FILIO_H
+#endif
+#endif
 extern int main(int argc, char **argv, char **env);
 #ifdef HAVE_LIBZEPHYR
 #endif
+#if OWL_STDERR_REDIR
+#endif
 #ifdef HAVE_LIBZEPHYR
 #endif
 #ifdef HAVE_USE_DEFAULT_COLORS
 #endif
 #ifdef HAVE_LIBZEPHYR
 #endif
+#if OWL_STDERR_REDIR
+#endif   
+#if 0
+#endif
 #ifdef HAVE_LIBZEPHYR
 #endif
 #ifdef HAVE_LIBZEPHYR
 #endif
-extern void sig_handler(int sig);
+extern void sig_handler(int sig, siginfo_t *si, void *data);
 extern void usage();
+#if OWL_STDERR_REDIR
+extern int stderr_replace(void);
+extern void stderr_redirect_handler(int handle, int rfd, int eventmask, void *data);
+#endif /* OWL_STDERR_REDIR */
 
 /* -------------------------------- pair.c -------------------------------- */
 extern void owl_pair_create(owl_pair *p, void *key, void *value);
@@ -784,7 +864,7 @@ extern char *owl_perlconfig_readconfig(char *file);
 extern int owl_perlconfig_is_function(char *fn);
 extern int owl_perlconfig_get_hashkeys(char *hashname, owl_list *l);
 extern char *owl_perlconfig_execute(char *line);
-extern char *owl_perlconfig_getmsg(owl_message *m, int mode, char *subname); 
+extern char *owl_perlconfig_getmsg(owl_message *m, int mode, char *subname);
 
 /* -------------------------------- perlglue.c -------------------------------- */
 #ifdef HAVE_LIBZEPHYR
@@ -794,6 +874,16 @@ extern char *owl_perlconfig_getmsg(owl_message *m, int mode, char *subname);
 
 /* -------------------------------- perlwrap.c -------------------------------- */
 
+/* -------------------------------- popexec.c -------------------------------- */
+#ifdef HAVE_SYS_IOCTL_H
+#endif
+#ifdef HAVE_SYS_FILIO_H
+#endif
+extern owl_popexec *owl_popexec_new(char *command);
+extern void owl_popexec_inputhandler(int handle, int fd, int eventmask, void *data);
+extern void owl_popexec_viewwin_onclose(owl_viewwin *vwin, void *data);
+extern void owl_popexec_unref(owl_popexec *pe);
+
 /* -------------------------------- popwin.c -------------------------------- */
 extern int owl_popwin_init(owl_popwin *pw);
 extern int owl_popwin_up(owl_popwin *pw);
@@ -812,6 +902,7 @@ extern void owl_popwin_no_needs_first_refresh(owl_popwin *pw);
 /* -------------------------------- regex.c -------------------------------- */
 extern void owl_regex_init(owl_regex *re);
 extern int owl_regex_create(owl_regex *re, char *string);
+extern int owl_regex_create_quoted(owl_regex *re, char *string);
 extern int owl_regex_compare(owl_regex *re, char *string);
 extern int owl_regex_is_set(owl_regex *re);
 extern char *owl_regex_get_string(owl_regex *re);
@@ -844,6 +935,11 @@ extern void owl_stylefunc_oneline(owl_fmtext *fm, owl_message *m);
 #endif
 #ifdef HAVE_LIBZEPHYR
 #endif
+extern void owl_stylefunc_vt(owl_fmtext *fm, owl_message *m);
+#ifdef HAVE_LIBZEPHYR
+#endif
+#ifdef HAVE_LIBZEPHYR
+#endif
 
 /* -------------------------------- tester.c -------------------------------- */
 extern void screeninit();
@@ -862,6 +958,13 @@ extern void owl_text_indent(char *out, char *in, int n);
 extern int owl_text_num_lines(char *in);
 extern char *owl_text_htmlstrip(char *in);
 extern char *owl_text_wordwrap(char *in, int col);
+extern void owl_text_wordunwrap(char *in);
+extern char *stristr(char *a, char *b);
+extern int only_whitespace(char *s);
+extern char *owl_getquoting(char *line);
+extern char *owl_text_substitute(char *in, char *from, char *to);
+extern void owl_text_tr(char *buff, char a, char b);
+extern char *owl_text_quote(char *in, char *toquote, char *quotestr);
 
 /* -------------------------------- timer.c -------------------------------- */
 extern void owl_timer_create_countup(owl_timer *t);
@@ -876,32 +979,29 @@ extern void sepbar(char *in);
 extern void pophandler_quit(int ch);
 extern char **atokenize(char *buffer, char *sep, int *i);
 extern char *skiptokens(char *buff, int n);
+extern char *owl_util_makepath(char *in);
 extern void atokenize_free(char **tok, int nels);
 extern void owl_parsefree(char **argv, int argc);
 extern char **owl_parseline(char *line, int *argc);
 extern char *owl_util_minutes_to_timestr(int in);
 extern int owl_util_find_trans(char *in, int len);
 extern void downstr(char *foo);
-extern char *stristr(char *a, char *b);
 extern char *owl_util_uniq(char *A, char *B, char *prohibit);
-extern int only_whitespace(char *s);
 extern void *owl_malloc(size_t size);
 extern void owl_free(void *ptr);
 extern char *owl_strdup(const char *s1);
 extern void *owl_realloc(void *ptr, size_t size);
 extern char *owl_sprintf(const char *fmt, ...);
-extern char *short_zuser(char *in);
-extern char *long_zuser(char *in);
-extern char *owl_util_smartstripped_user(char *in);
-extern char *owl_getquoting(char *line);
-extern char *owl_util_substitute(char *in, char *from, char *to);
-extern void owl_util_tr(char *buff, char a, char b);
 extern int owl_util_string_to_color(char *color);
 extern char *owl_util_color_to_string(int color);
 extern char *owl_util_get_default_tty();
 extern void owl_hack_animate();
 extern char *owl_util_stripnewlines(char *in);
 extern void owl_util_file_deleteline(char *filename, char *line, int backup);
+extern void owl_util_list_add_unique_string(owl_list *list, char *str);
+extern int owl_util_common_strings_in_lists(owl_list *a, owl_list *b);
+extern int owl_util_max(int a, int b);
+extern int owl_util_min(int a, int b);
 #ifdef OWL_INCLUDE_REG_TESTS
 extern int owl_util_regtest(void);
 #endif /* OWL_INCLUDE_REG_TESTS */
@@ -911,6 +1011,8 @@ extern int owl_variable_int_validate_gt0(owl_variable *v, void *newval);
 extern int owl_variable_int_validate_positive(owl_variable *v, void *newval);
 extern int owl_variable_typewinsize_set(owl_variable *v, void *newval);
 extern int owl_variable_debug_set(owl_variable *v, void *newval);
+extern int owl_variable_aaway_set(owl_variable *v, void *newval);
+extern int owl_variable_pseudologins_set(owl_variable *v, void *newval);
 extern int owl_variable_disable_ctrl_d_set(owl_variable *v, void *newval);
 extern int owl_variable_tty_set(owl_variable *v, void *newval);
 extern int owl_variable_dict_setup(owl_vardict *vd);
@@ -957,9 +1059,8 @@ extern int owl_variable_regtest(void);
 #endif /* OWL_INCLUDE_REG_TESTS */
 
 /* -------------------------------- varstubs.c -------------------------------- */
-extern void owl_global_set_personalbell_on(owl_global *g);
-extern void owl_global_set_personalbell_off(owl_global *g);
-extern int owl_global_is_personalbell(owl_global *g);
+extern void owl_global_set_personalbell(owl_global *g, char *text);
+extern char *owl_global_get_personalbell(owl_global *g);
 extern void owl_global_set_bell_on(owl_global *g);
 extern void owl_global_set_bell_off(owl_global *g);
 extern int owl_global_is_bell(owl_global *g);
@@ -999,12 +1100,28 @@ extern int owl_global_is_logging(owl_global *g);
 extern void owl_global_set_classlogging_on(owl_global *g);
 extern void owl_global_set_classlogging_off(owl_global *g);
 extern int owl_global_is_classlogging(owl_global *g);
+extern void owl_global_set_loggingdirection(owl_global *g, int n);
+extern int owl_global_get_loggingdirection(owl_global *g);
 extern void owl_global_set_colorztext_on(owl_global *g);
 extern void owl_global_set_colorztext_off(owl_global *g);
 extern int owl_global_is_colorztext(owl_global *g);
+extern void owl_global_set_fancylines_on(owl_global *g);
+extern void owl_global_set_fancylines_off(owl_global *g);
+extern int owl_global_is_fancylines(owl_global *g);
 extern void owl_global_set_zcrypt_on(owl_global *g);
 extern void owl_global_set_zcrypt_off(owl_global *g);
 extern int owl_global_is_zcrypt(owl_global *g);
+extern void owl_global_set_pseudologins_on(owl_global *g);
+extern void owl_global_set_pseudologins_off(owl_global *g);
+extern int owl_global_is_pseudologins(owl_global *g);
+extern void owl_global_set_ignorelogins_on(owl_global *g);
+extern void owl_global_set_ignorelogins_off(owl_global *g);
+extern int owl_global_is_ignorelogins(owl_global *g);
+extern void owl_global_set_logfilter(owl_global *g, char *text);
+extern char *owl_global_get_logfilter(owl_global *g);
+extern void owl_global_set_loglogins_on(owl_global *g);
+extern void owl_global_set_loglogins_off(owl_global *g);
+extern int owl_global_is_loglogins(owl_global *g);
 extern void owl_global_set_lockout_ctrld(owl_global *g, int n);
 extern int owl_global_get_lockout_ctrld(owl_global *g);
 extern void owl_global_set_burningears_on(owl_global *g);
@@ -1034,6 +1151,13 @@ extern void owl_global_set_zaway_msg(owl_global *g, char *text);
 extern char *owl_global_get_zaway_msg(owl_global *g);
 extern void owl_global_set_zaway_msg_default(owl_global *g, char *text);
 extern char *owl_global_get_zaway_msg_default(owl_global *g);
+extern void owl_global_set_aaway_on(owl_global *g);
+extern void owl_global_set_aaway_off(owl_global *g);
+extern int owl_global_is_aaway(owl_global *g);
+extern void owl_global_set_aaway_msg(owl_global *g, char *text);
+extern char *owl_global_get_aaway_msg(owl_global *g);
+extern void owl_global_set_aaway_msg_default(owl_global *g, char *text);
+extern char *owl_global_get_aaway_msg_default(owl_global *g);
 extern void owl_global_set_view_home(owl_global *g, char *text);
 extern char *owl_global_get_view_home(owl_global *g);
 extern void owl_global_set_alert_filter(owl_global *g, char *text);
@@ -1082,8 +1206,10 @@ extern void owl_view_free(owl_view *v);
 
 /* -------------------------------- viewwin.c -------------------------------- */
 extern void owl_viewwin_init_text(owl_viewwin *v, WINDOW *win, int winlines, int wincols, char *text);
+extern void owl_viewwin_append_text(owl_viewwin *v, char *text);
 extern void owl_viewwin_init_fmtext(owl_viewwin *v, WINDOW *win, int winlines, int wincols, owl_fmtext *fmtext);
 extern void owl_viewwin_set_curswin(owl_viewwin *v, WINDOW *w, int winlines, int wincols);
+extern void owl_viewwin_set_onclose_hook(owl_viewwin *v, void (*onclose_hook) (owl_viewwin *vwin, void *data), void *onclose_hook_data);
 extern void owl_viewwin_redisplay(owl_viewwin *v, int update);
 extern void owl_viewwin_pagedown(owl_viewwin *v);
 extern void owl_viewwin_linedown(owl_viewwin *v);
@@ -1095,6 +1221,12 @@ extern void owl_viewwin_top(owl_viewwin *v);
 extern void owl_viewwin_bottom(owl_viewwin *v);
 extern void owl_viewwin_free(owl_viewwin *v);
 
+/* -------------------------------- zbuddylist.c -------------------------------- */
+extern void owl_zbuddylist_create(owl_zbuddylist *zb);
+extern int owl_zbuddylist_adduser(owl_zbuddylist *zb, char *name);
+extern int owl_zbuddylist_deluser(owl_zbuddylist *zb, char *name);
+extern int owl_zbuddylist_contains_user(owl_zbuddylist *zb, char *name);
+
 /* -------------------------------- zcrypt.c -------------------------------- */
 #ifdef OWL_ENABLE_ZCRYPT
 #ifndef TRUE
@@ -1137,7 +1269,11 @@ extern char *owl_zephyr_get_sender();
 #ifdef HAVE_LIBZEPHYR
 #else
 #endif
-extern int owl_zephyr_loadsubs(char *filename);
+extern int owl_zephyr_loadsubs(char *filename, int error_on_nofile);
+#ifdef HAVE_LIBZEPHYR
+#else
+#endif
+extern int owl_zephyr_loaddefaultsubs();
 #ifdef HAVE_LIBZEPHYR
 #else
 #endif
@@ -1157,9 +1293,9 @@ extern int owl_zephyr_unsub(char *class, char *inst, char *recip);
 #else
 #endif
 #ifdef HAVE_LIBZEPHYR
-extern char *owl_zephyr_get_field(ZNotice_t *n, int j, int *k);
+extern char *owl_zephyr_get_field(ZNotice_t *n, int j);
 #else
-extern char *owl_zephyr_get_field(void *n, int j, int *k);
+extern char *owl_zephyr_get_field(void *n, int j);
 #endif
 #ifdef HAVE_LIBZEPHYR
 extern int owl_zephyr_get_num_fields(ZNotice_t *n);
@@ -1167,7 +1303,7 @@ extern int owl_zephyr_get_num_fields(ZNotice_t *n);
 extern int owl_zephyr_get_num_fields(void *n);
 #endif
 #ifdef HAVE_LIBZEPHYR
-extern char *owl_zephyr_get_message(ZNotice_t *n, int *k);
+extern char *owl_zephyr_get_message(ZNotice_t *n);
 #endif
 #ifdef HAVE_LIBZEPHYR
 extern char *owl_zephyr_get_zsig(ZNotice_t *n, int *k);
@@ -1234,9 +1370,18 @@ extern char *owl_zephyr_get_variable(char *var);
 extern void owl_zephyr_set_locationinfo(char *host, char *val);
 #ifdef HAVE_LIBZEPHYR
 #endif
+extern char *short_zuser(char *in);
+extern char *long_zuser(char *in);
+extern char *owl_zephyr_smartstripped_user(char *in);
+extern int owl_zephyr_get_anyone_list(owl_list *in, char *filename);
+#ifdef HAVE_LIBZEPHYR
+#else
+#endif
 
 /* -------------------------------- zwrite.c -------------------------------- */
 extern int owl_zwrite_create_from_line(owl_zwrite *z, char *line);
+#if !(OWL_STDERR_REDIR)
+#endif
 extern void owl_zwrite_send_ping(owl_zwrite *z);
 extern void owl_zwrite_set_message(owl_zwrite *z, char *msg);
 extern char *owl_zwrite_get_message(owl_zwrite *z);
