@@ -8,7 +8,7 @@
 #include <perl.h>
 #include "XSUB.h"
 
-static const char fileIdent[] = "$Id: perlconfig.c,v 1.4 2003/12/23 21:38:44 kretch Exp $";
+static const char fileIdent[] = "$Id: perlconfig.c,v 1.5 2005/01/03 21:53:33 kretch Exp $";
 
 extern char *owl_perlwrap_codebuff;
 
@@ -151,10 +151,11 @@ char *owl_perlconfig_call_with_message(char *subname, owl_message *m)
 
 char *owl_perlconfig_readconfig(char *file)
 {
-  int ret;
+  int ret, fd;
   PerlInterpreter *p;
   char filename[1024];
   char *embedding[5];
+  char *err;
   struct stat statbuff;
 
   if (file==NULL) {
@@ -173,27 +174,42 @@ char *owl_perlconfig_readconfig(char *file)
 
   owl_global_set_no_have_config(&g);
 
+  /* Before we let perl have at it, we'll do our own checks on the the
+   *  file to see if it's present, readnable etc.
+   */
+
+  /* Not present, start without it */
   ret=stat(filename, &statbuff);
   if (ret) {
-    return NULL;
+    return(NULL);
   }
 
+  /* present, but stat thinks it's unreadable */
+  if (! (statbuff.st_mode & S_IREAD)) {
+    return(owl_sprintf("%s present but not readable", filename));
+  }
+
+  /* can we open it? */
+  fd=open(filename, O_RDONLY);
+  if (fd==-1) {
+    return(owl_sprintf("could not open %s for reading", filename));
+  }
+  close(fd);
+
   ret=perl_parse(p, owl_perl_xs_init, 2, embedding, NULL);
   if (ret || SvTRUE(ERRSV)) {
     STRLEN n_a;
-    char *err;
-    err = owl_strdup(SvPV(ERRSV, n_a));
-    sv_setsv (ERRSV, &PL_sv_undef);     /* and clear the error */
-    return err;
+    err=owl_strdup(SvPV(ERRSV, n_a));
+    sv_setsv(ERRSV, &PL_sv_undef);     /* and clear the error */
+    return(err);
   }
 
   ret=perl_run(p);
   if (ret || SvTRUE(ERRSV)) {
     STRLEN n_a;
-    char *err;
-    err = owl_strdup(SvPV(ERRSV, n_a));
-    sv_setsv (ERRSV, &PL_sv_undef);     /* and clear the error */
-    return err;
+    err=owl_strdup(SvPV(ERRSV, n_a));
+    sv_setsv(ERRSV, &PL_sv_undef);     /* and clear the error */
+    return(err);
   }
 
   owl_global_set_have_config(&g);
@@ -216,10 +232,9 @@ char *owl_perlconfig_readconfig(char *file)
 
   if (SvTRUE(ERRSV)) {
     STRLEN n_a;
-    char *err;
-    err = owl_strdup(SvPV(ERRSV, n_a));
+    err=owl_strdup(SvPV(ERRSV, n_a));
     sv_setsv (ERRSV, &PL_sv_undef);     /* and clear the error */
-    return err;
+    return(err);
   }
 
   /* check if we have the formatting function */
