@@ -6,7 +6,7 @@
 #include <string.h>
 #include "owl.h"
 
-static const char fileIdent[] = "$Id: zephyr.c,v 1.47 2004/04/18 15:55:42 kretch Exp $";
+static const char fileIdent[] = "$Id: zephyr.c,v 1.52 2005/01/05 04:29:48 kretch Exp $";
 
 #ifdef HAVE_LIBZEPHYR
 Code_t ZResetAuthentication();
@@ -66,11 +66,15 @@ char *owl_zephyr_get_sender()
 #endif
 }
 
-/* return 0  on success
- *        -1 on file error
- *        -2 on subscription error
+/* Load zephyr subscriptions form 'filename'.  If 'filename' is NULL,
+ * the default file $HOME/.zephyr.subs will be used.
+ *
+ * Returns 0 on success.  If the file does not exist, return -1 if
+ * 'error_on_nofile' is 1, otherwise return 0.  Return -1 if the file
+ * exists but can not be read.  Return -2 if there is a failure from
+ * zephyr to load the subscriptions.
  */
-int owl_zephyr_loadsubs(char *filename)
+int owl_zephyr_loadsubs(char *filename, int error_on_nofile)
 {
 #ifdef HAVE_LIBZEPHYR
   FILE *file;
@@ -87,48 +91,46 @@ int owl_zephyr_loadsubs(char *filename)
   }
 
   ret=stat(subsfile, &statbuff);
-  if (ret) return(0);
-
-  ret=0;
+  if (ret) {
+    if (error_on_nofile==1) return(-1);
+    return(0);
+  }
 
   ZResetAuthentication();
   /* need to redo this to do chunks, not just bail after 3000 */
   count=0;
   file=fopen(subsfile, "r");
-  if (file) {
-    while ( fgets(buffer, 1024, file)!=NULL ) {
-      if (buffer[0]=='#' || buffer[0]=='\n' || buffer[0]=='\n') continue;
-
-      if (buffer[0]=='-') {
-	start=buffer+1;
-      } else {
-	start=buffer;
-      }
-      
-      if (count >= 3000) break; /* also tell the user */
-
-      /* add it to the list of subs */
-      if ((tmp=(char *) strtok(start, ",\n\r"))==NULL) continue;
-      subs[count].zsub_class=owl_strdup(tmp);
-      if ((tmp=(char *) strtok(NULL, ",\n\r"))==NULL) continue;
-      subs[count].zsub_classinst=owl_strdup(tmp);
-      if ((tmp=(char *) strtok(NULL, " \t\n\r"))==NULL) continue;
-      subs[count].zsub_recipient=owl_strdup(tmp);
-
-      /* if it started with '-' then add it to the global punt list */
-      if (buffer[0]=='-') {
-	owl_function_zpunt(subs[count].zsub_class, subs[count].zsub_classinst, subs[count].zsub_recipient, 0);
-      }
-      
-      count++;
+  if (!file) return(-1);
+  while ( fgets(buffer, 1024, file)!=NULL ) {
+    if (buffer[0]=='#' || buffer[0]=='\n' || buffer[0]=='\n') continue;
+    
+    if (buffer[0]=='-') {
+      start=buffer+1;
+    } else {
+      start=buffer;
     }
-    fclose(file);
-  } else {
-    count=0;
-    ret=-1;
+    
+    if (count >= 3000) break; /* also tell the user */
+    
+    /* add it to the list of subs */
+    if ((tmp=(char *) strtok(start, ",\n\r"))==NULL) continue;
+    subs[count].zsub_class=owl_strdup(tmp);
+    if ((tmp=(char *) strtok(NULL, ",\n\r"))==NULL) continue;
+    subs[count].zsub_classinst=owl_strdup(tmp);
+    if ((tmp=(char *) strtok(NULL, " \t\n\r"))==NULL) continue;
+    subs[count].zsub_recipient=owl_strdup(tmp);
+    
+    /* if it started with '-' then add it to the global punt list */
+    if (buffer[0]=='-') {
+      owl_function_zpunt(subs[count].zsub_class, subs[count].zsub_classinst, subs[count].zsub_recipient, 0);
+    }
+    
+    count++;
   }
+  fclose(file);
 
   /* sub without defaults */
+  ret=0;
   if (ZSubscribeToSansDefaults(subs,count,0) != ZERR_NONE) {
     owl_function_error("Error subscribing to zephyr notifications.");
     ret=-2;
@@ -477,12 +479,10 @@ void owl_zephyr_handle_ack(ZNotice_t *retnotice)
     } else {
       char buff[1024];
       tmp = short_zuser(retnotice->z_recipient);
-      owl_function_error("%s: Not logged in or subscribing to messages.", 
-			   tmp);
-
+      owl_function_error("%s: Not logged in or subscribing to messages.", tmp);
       sprintf(buff, "Could not send message to %s: not logged in or subscribing to messages.\n", tmp);
       owl_function_adminmsg("", buff);
-      if (owl_global_is_logging(&g)) owl_log_outgoing_zephyr_error(tmp, buff);
+      owl_log_outgoing_zephyr_error(tmp, buff);
       owl_free(tmp);
     }
   } else {
@@ -515,6 +515,7 @@ void owl_zephyr_zaway(owl_message *m)
 {
 #ifdef HAVE_LIBZEPHYR
   char *tmpbuff, *myuser, *to;
+  owl_message *mout;
   
   /* bail if it doesn't look like a message we should reply to.  Some
    * of this defined by the way zaway(1) works
@@ -551,7 +552,8 @@ void owl_zephyr_zaway(owl_message *m)
   owl_free(to);
 
   /* display the message as an admin message in the receive window */
-  owl_function_make_outgoing_zephyr(owl_global_get_zaway_msg(&g), tmpbuff, "Automated reply:");
+  mout=owl_function_make_outgoing_zephyr(owl_global_get_zaway_msg(&g), tmpbuff, "Automated reply:");
+  owl_function_add_message(mout);
   owl_free(tmpbuff);
 #endif
 }
@@ -582,7 +584,8 @@ void owl_zephyr_zlocate(char *user, char *out, int auth)
   ZResetAuthentication();
   ret=ZLocateUser(user,&numlocs,auth?ZAUTH:ZNOAUTH);
   if (ret != ZERR_NONE) {
-    owl_function_error("Error locating user %s", user);
+    sprintf(out, "Error locating user %s\n", user);
+    return;
   }
 
   if (numlocs==0) {
@@ -595,7 +598,10 @@ void owl_zephyr_zlocate(char *user, char *out, int auth)
   for (;numlocs;numlocs--) {
     ZGetLocations(&locations,&one);
     myuser=short_zuser(user);
-    sprintf(out, "%s%s: %s\t%s\t%s\n", out, myuser, locations.host, locations.tty, locations.time);
+    sprintf(out, "%s%s: %s\t%s\t%s\n", out, myuser,
+	    locations.host ? locations.host : "?",
+	    locations.tty ? locations.tty : "?",
+	    locations.time ? locations.time : "?");
     owl_free(myuser);
   }
 #endif
@@ -615,18 +621,15 @@ void owl_zephyr_addsub(char *filename, char *class, char *inst, char *recip)
     strcpy(subsfile, filename);
   }
 
-  /* first check if it exists already */
+  /* if the file already exists, check to see if the sub is already there */
   file=fopen(subsfile, "r");
-  if (!file) {
-    owl_function_error("Error opening file %s", subsfile);
-    owl_free(line);
-    return;
-  }
-  while (fgets(buff, LINE, file)!=NULL) {
-    if (!strcasecmp(buff, line)) {
-      owl_function_error("Subscription already present in %s", subsfile);
-      owl_free(line);
-      return;
+  if (file) {
+    while (fgets(buff, LINE, file)!=NULL) {
+      if (!strcasecmp(buff, line)) {
+	owl_function_error("Subscription already present in %s", subsfile);
+	owl_free(line);
+	return;
+      }
     }
   }
 
